diff --git a/doc/de/Makefile.am b/doc/de/Makefile.am
index 4f7f54b5e..35741d472 100644
--- a/doc/de/Makefile.am
+++ b/doc/de/Makefile.am
@@ -23,6 +23,7 @@ BOOK_AUTOGEN_INCLUDE = ../include_autogen.xml \
autogen/aspell_options.xml \
autogen/charset_commands.xml \
autogen/charset_options.xml \
+ autogen/completions.xml \
autogen/demo_commands.xml \
autogen/fifo_infos.xml \
autogen/irc_commands.xml \
diff --git a/doc/de/autogen/completions.xml b/doc/de/autogen/completions.xml
new file mode 100644
index 000000000..946666323
--- /dev/null
+++ b/doc/de/autogen/completions.xml
@@ -0,0 +1,203 @@
+
+
+
+
+ alias
+ alias
+ list of alias
+
+
+ aspell
+ aspell_langs
+ list of supported langs for aspell
+
+
+ irc
+ irc_channel
+ current IRC channel
+
+
+ irc
+ irc_channel_nicks_hosts
+ nicks and hostnames of current IRC channel
+
+
+ irc
+ irc_channel_topic
+ topic of current IRC channel
+
+
+ irc
+ irc_channels
+ IRC channels (on all servers)
+
+
+ irc
+ irc_ignores_numbers
+ numbers for defined ignores
+
+
+ irc
+ irc_msg_part
+ default part message for IRC channel
+
+
+ irc
+ irc_server
+ current IRC server
+
+
+ irc
+ irc_server_nick
+ nick on current IRC server
+
+
+ irc
+ irc_server_nicks
+ nicks on all channels of current IRC server
+
+
+ irc
+ irc_servers
+ IRC servers (internal names)
+
+
+ irc
+ nick
+ nicks of current IRC channel
+
+
+ lua
+ lua_script
+ list of scripts
+
+
+ perl
+ perl_script
+ list of scripts
+
+
+ python
+ python_script
+ list of scripts
+
+
+ ruby
+ ruby_script
+ list of scripts
+
+
+ tcl
+ tcl_script
+ list of scripts
+
+
+ weechat
+ bars_names
+ names of bars
+
+
+ weechat
+ bars_options
+ options for bars
+
+
+ weechat
+ buffers_names
+ names of buffers
+
+
+ weechat
+ buffers_numbers
+ numbers of buffers
+
+
+ weechat
+ buffers_plugins_names
+ names of buffers (including plugins names)
+
+
+ weechat
+ commands
+ commands (weechat and plugins)
+
+
+ weechat
+ config_files
+ configuration files
+
+
+ weechat
+ config_option_values
+ values for a configuration option
+
+
+ weechat
+ config_options
+ configuration options
+
+
+ weechat
+ filename
+ filename
+
+
+ weechat
+ filters_names
+ names of filters
+
+
+ weechat
+ infolists
+ names of infolists hooked
+
+
+ weechat
+ infos
+ names of infos hooked
+
+
+ weechat
+ keys_codes
+ key codes
+
+
+ weechat
+ nicks
+ nicks in nicklist of current buffer
+
+
+ weechat
+ plugins_commands
+ commands defined by plugins
+
+
+ weechat
+ plugins_names
+ names of plugins
+
+
+ weechat
+ proxies_names
+ names of proxies
+
+
+ weechat
+ proxies_options
+ options for proxies
+
+
+ weechat
+ weechat_commands
+ weechat commands
+
+
+ xfer
+ nick
+ nicks of DCC chat
+
diff --git a/doc/de/autogen/weechat_commands.xml b/doc/de/autogen/weechat_commands.xml
index 5e4e6be3c..b385619bd 100644
--- a/doc/de/autogen/weechat_commands.xml
+++ b/doc/de/autogen/weechat_commands.xml
@@ -150,14 +150,14 @@ functions for command line
Cette commande est utilisée par les associations de touches ou les extensions.
-/key [key [command [args]]] | [unbind key] | [reset -yes] | [missing]
+/key [bind key [command [args]]] | [unbind key] | [reset -yes] | [missing]
belegen/freigeben von Tasten
- key: display or bind this key to a command
- unbind: unbind a key
- reset: restore bindings to the default values and delete ALL personal bindings (use carefully!)
- missing: add missing keys (using default bindings)
+ bind: bind a command to a key or display command bound to key
+ unbind: remove a key binding
+ reset: restore bindings to the default values and delete ALL personal bindings (use carefully!)
+missing: add missing keys (using default bindings)
/layout [[save | apply | reset] [buffers | windows]]
diff --git a/doc/de/autogen/weechat_options.xml b/doc/de/autogen/weechat_options.xml
index ead661fea..b1c9deed1 100644
--- a/doc/de/autogen/weechat_options.xml
+++ b/doc/de/autogen/weechat_options.xml
@@ -572,7 +572,7 @@
type: string
- values: any string (default value: '%n|%(irc_channels)')
+ values: any string (default value: '%(nicks)|%(irc_channels)')
diff --git a/doc/de/dev/plugin_c_api.de.xml b/doc/de/dev/plugin_c_api.de.xml
index 669a13179..e04330536 100644
--- a/doc/de/dev/plugin_c_api.de.xml
+++ b/doc/de/dev/plugin_c_api.de.xml
@@ -1836,7 +1836,7 @@ void weechat_exec_on_files (
: function called for each file
found, arguments:
-
+
Type
@@ -2490,7 +2490,7 @@ struct t_config_file *weechat_config_new (
configuration file is reloaded with /reload (optional, may be
NULL), arguments:
-
+
Type
@@ -2629,7 +2629,7 @@ struct t_config_section *weechat_config_new_section (
except if options in your section need custom function),
arguments:
-
+
Type
@@ -2681,7 +2681,7 @@ struct t_config_section *weechat_config_new_section (
is written in file (should be NULL for most cases, except if your
section needs to be written by a custom function), arguments:
-
+
Type
@@ -2727,7 +2727,7 @@ struct t_config_section *weechat_config_new_section (
: callback called when
default values for section must be written in file, arguments:
-
+
Type
@@ -2769,7 +2769,7 @@ struct t_config_section *weechat_config_new_section (
new option is created in section (NULL if section does not allow
new options to be created), arguments:
-
+
Type
@@ -2821,7 +2821,7 @@ struct t_config_section *weechat_config_new_section (
option is deleted (NULL if section does not allow options to be
deleted), arguments:
-
+
Type
@@ -3095,7 +3095,7 @@ struct t_config_option *weechat_config_new_option (
: callback called to check
new value for an option (optional), arguments:
-
+
Type
@@ -3136,7 +3136,7 @@ struct t_config_option *weechat_config_new_option (
: callback called when value of
option has changed (optional), arguments:
-
+
Type
@@ -3172,7 +3172,7 @@ struct t_config_option *weechat_config_new_option (
: callback called when option
will be deleted (optional), arguments:
-
+
Type
@@ -3727,7 +3727,7 @@ void *weechat_config_option_get_pointer (
: property name:
-
+
Property
@@ -4656,7 +4656,7 @@ const char *weechat_prefix (const char *prefix);
: name of prefix:
-
+
Prefix
@@ -5036,12 +5036,27 @@ struct t_hook *weechat_hook_command (
list of completions for each arguments, separated by space. Many
completions are possible for one argument, separated by "|".
Default completion codes are:
+
+
+
+
+ Plugin
+ Code
+ Description
+
+
+
+ &completions.xml;
+
+
+
+ Special codes:
Code
- Completion
+ Description
@@ -5053,71 +5068,6 @@ struct t_hook *weechat_hook_command (
%*
Repeat last completion
-
- %b
- Buffers names
-
-
- %B
- Buffers names (with plugin name)
-
-
- %c
- Configuration files
-
-
- %f
- Filename
-
-
- %F
- Filters
-
-
- %h
- Commands hooked
-
-
- %i
- Infos hooked
-
-
- %I
- Infolists hooked
-
-
- %n
- Nick
-
-
- %o
- Configuration option
-
-
- %p
- Plugin name
-
-
- %P
- Plugin commands
-
-
- %r
- Bar names
-
-
- %v
- Value of configuration option
-
-
- %w
- WeeChat commands
-
-
- %(xxx)
- Custom completion by plugin (xxx is a completion
- code added by a plugin)
-
@@ -5128,7 +5078,7 @@ struct t_hook *weechat_hook_command (
: function called when command is used,
arguments:
-
+
Type
@@ -5244,7 +5194,7 @@ struct t_hook *weechat_hook_command_run (
: function called when command is run,
arguments:
-
+
Type
@@ -5351,7 +5301,7 @@ struct t_hook *weechat_hook_timer (
: function called when time is reached,
arguments:
-
+
Type
@@ -5452,7 +5402,7 @@ struct t_hook *weechat_hook_fd (
: function called when a selected event
occurs, arguments:
-
+
Type
@@ -5546,7 +5496,7 @@ struct t_hook *weechat_hook_process (
: function called when data from child
is available, or when child has ended, arguments:
-
+
Type
@@ -5684,7 +5634,7 @@ struct t_hook *weechat_hook_connect (
: function called when connection is ok
or failed, arguments:
-
+
Type
@@ -5858,7 +5808,7 @@ struct t_hook *weechat_hook_print (
: function called when message is
printed, arguments:
-
+
Type
@@ -5981,7 +5931,7 @@ struct t_hook *weechat_hook_signal (
: function called when signal is
received, arguments:
-
+
Type
@@ -6124,7 +6074,7 @@ struct t_hook *weechat_hook_config (
: function called when configuration
option is changed, arguments:
-
+
Type
@@ -6217,7 +6167,7 @@ struct t_hook *weechat_hook_completion (
is used (user is completing something using this item),
arguments:
-
+
Type
@@ -6383,7 +6333,7 @@ struct t_hook *weechat_hook_modifier (
: function called when modifier is
received, arguments:
-
+
Type
@@ -6547,7 +6497,7 @@ struct t_hook *weechat_hook_info (
: function called when info is asked,
arguments:
-
+
Type
@@ -6642,7 +6592,7 @@ struct t_hook *weechat_hook_infolist (
: function called when infolist is asked,
arguments:
-
+
Type
@@ -6805,7 +6755,7 @@ struct t_gui_buffer *weechat_buffer_new (
: function called when input text
is entered on buffer, arguments:
-
+
Type
@@ -6845,7 +6795,7 @@ struct t_gui_buffer *weechat_buffer_new (
: function called when buffer is
closed, arguments:
-
+
Type
@@ -7294,7 +7244,7 @@ void weechat_buffer_set (struct t_gui_buffer *buffer, const char *property,
: property name:
-
+
Name
@@ -7522,7 +7472,7 @@ void weechat_buffer_set_pointer (struct t_gui_buffer *buffer, const char *proper
: property name:
-
+
Name
@@ -9005,7 +8955,7 @@ const char *weechat_info_get (const char *info_name,
core or other plugin (see plugin doc for infos returned by
each plugin). WeeChat core infos are:
-
+
Info
diff --git a/doc/en/Makefile.am b/doc/en/Makefile.am
index 030d8e9c5..641fcdc6f 100644
--- a/doc/en/Makefile.am
+++ b/doc/en/Makefile.am
@@ -23,6 +23,7 @@ BOOK_AUTOGEN_INCLUDE = ../include_autogen.xml \
autogen/aspell_options.xml \
autogen/charset_commands.xml \
autogen/charset_options.xml \
+ autogen/completions.xml \
autogen/demo_commands.xml \
autogen/fifo_infos.xml \
autogen/irc_commands.xml \
diff --git a/doc/en/autogen/completions.xml b/doc/en/autogen/completions.xml
new file mode 100644
index 000000000..946666323
--- /dev/null
+++ b/doc/en/autogen/completions.xml
@@ -0,0 +1,203 @@
+
+
+
+
+ alias
+ alias
+ list of alias
+
+
+ aspell
+ aspell_langs
+ list of supported langs for aspell
+
+
+ irc
+ irc_channel
+ current IRC channel
+
+
+ irc
+ irc_channel_nicks_hosts
+ nicks and hostnames of current IRC channel
+
+
+ irc
+ irc_channel_topic
+ topic of current IRC channel
+
+
+ irc
+ irc_channels
+ IRC channels (on all servers)
+
+
+ irc
+ irc_ignores_numbers
+ numbers for defined ignores
+
+
+ irc
+ irc_msg_part
+ default part message for IRC channel
+
+
+ irc
+ irc_server
+ current IRC server
+
+
+ irc
+ irc_server_nick
+ nick on current IRC server
+
+
+ irc
+ irc_server_nicks
+ nicks on all channels of current IRC server
+
+
+ irc
+ irc_servers
+ IRC servers (internal names)
+
+
+ irc
+ nick
+ nicks of current IRC channel
+
+
+ lua
+ lua_script
+ list of scripts
+
+
+ perl
+ perl_script
+ list of scripts
+
+
+ python
+ python_script
+ list of scripts
+
+
+ ruby
+ ruby_script
+ list of scripts
+
+
+ tcl
+ tcl_script
+ list of scripts
+
+
+ weechat
+ bars_names
+ names of bars
+
+
+ weechat
+ bars_options
+ options for bars
+
+
+ weechat
+ buffers_names
+ names of buffers
+
+
+ weechat
+ buffers_numbers
+ numbers of buffers
+
+
+ weechat
+ buffers_plugins_names
+ names of buffers (including plugins names)
+
+
+ weechat
+ commands
+ commands (weechat and plugins)
+
+
+ weechat
+ config_files
+ configuration files
+
+
+ weechat
+ config_option_values
+ values for a configuration option
+
+
+ weechat
+ config_options
+ configuration options
+
+
+ weechat
+ filename
+ filename
+
+
+ weechat
+ filters_names
+ names of filters
+
+
+ weechat
+ infolists
+ names of infolists hooked
+
+
+ weechat
+ infos
+ names of infos hooked
+
+
+ weechat
+ keys_codes
+ key codes
+
+
+ weechat
+ nicks
+ nicks in nicklist of current buffer
+
+
+ weechat
+ plugins_commands
+ commands defined by plugins
+
+
+ weechat
+ plugins_names
+ names of plugins
+
+
+ weechat
+ proxies_names
+ names of proxies
+
+
+ weechat
+ proxies_options
+ options for proxies
+
+
+ weechat
+ weechat_commands
+ weechat commands
+
+
+ xfer
+ nick
+ nicks of DCC chat
+
diff --git a/doc/en/autogen/weechat_commands.xml b/doc/en/autogen/weechat_commands.xml
index e9740ea33..fb714edf6 100644
--- a/doc/en/autogen/weechat_commands.xml
+++ b/doc/en/autogen/weechat_commands.xml
@@ -150,14 +150,14 @@ functions for command line
Cette commande est utilisée par les associations de touches ou les extensions.
-/key [key [command [args]]] | [unbind key] | [reset -yes] | [missing]
+/key [bind key [command [args]]] | [unbind key] | [reset -yes] | [missing]
bind/unbind keys
- key: display or bind this key to a command
- unbind: unbind a key
- reset: restore bindings to the default values and delete ALL personal bindings (use carefully!)
- missing: add missing keys (using default bindings)
+ bind: bind a command to a key or display command bound to key
+ unbind: remove a key binding
+ reset: restore bindings to the default values and delete ALL personal bindings (use carefully!)
+missing: add missing keys (using default bindings)
/layout [[save | apply | reset] [buffers | windows]]
diff --git a/doc/en/autogen/weechat_options.xml b/doc/en/autogen/weechat_options.xml
index 0015063b2..20779ea41 100644
--- a/doc/en/autogen/weechat_options.xml
+++ b/doc/en/autogen/weechat_options.xml
@@ -572,7 +572,7 @@
type: string
- values: any string (default value: '%n|%(irc_channels)')
+ values: any string (default value: '%(nicks)|%(irc_channels)')
diff --git a/doc/en/dev/plugin_c_api.en.xml b/doc/en/dev/plugin_c_api.en.xml
index b5f01bff4..f4a50efd7 100644
--- a/doc/en/dev/plugin_c_api.en.xml
+++ b/doc/en/dev/plugin_c_api.en.xml
@@ -1835,7 +1835,7 @@ void weechat_exec_on_files (
: function called for each file
found, arguments:
-
+
Type
@@ -2489,7 +2489,7 @@ struct t_config_file *weechat_config_new (
configuration file is reloaded with /reload (optional, may be
NULL), arguments:
-
+
Type
@@ -2628,7 +2628,7 @@ struct t_config_section *weechat_config_new_section (
except if options in your section need custom function),
arguments:
-
+
Type
@@ -2680,7 +2680,7 @@ struct t_config_section *weechat_config_new_section (
is written in file (should be NULL for most cases, except if your
section needs to be written by a custom function), arguments:
-
+
Type
@@ -2726,7 +2726,7 @@ struct t_config_section *weechat_config_new_section (
: callback called when
default values for section must be written in file, arguments:
-
+
Type
@@ -2768,7 +2768,7 @@ struct t_config_section *weechat_config_new_section (
new option is created in section (NULL if section does not allow
new options to be created), arguments:
-
+
Type
@@ -2820,7 +2820,7 @@ struct t_config_section *weechat_config_new_section (
option is deleted (NULL if section does not allow options to be
deleted), arguments:
-
+
Type
@@ -3094,7 +3094,7 @@ struct t_config_option *weechat_config_new_option (
: callback called to check
new value for an option (optional), arguments:
-
+
Type
@@ -3135,7 +3135,7 @@ struct t_config_option *weechat_config_new_option (
: callback called when value of
option has changed (optional), arguments:
-
+
Type
@@ -3171,7 +3171,7 @@ struct t_config_option *weechat_config_new_option (
: callback called when option
will be deleted (optional), arguments:
-
+
Type
@@ -3726,7 +3726,7 @@ void *weechat_config_option_get_pointer (
: property name:
-
+
Property
@@ -4655,7 +4655,7 @@ const char *weechat_prefix (const char *prefix);
: name of prefix:
-
+
Prefix
@@ -5035,12 +5035,27 @@ struct t_hook *weechat_hook_command (
list of completions for each arguments, separated by space. Many
completions are possible for one argument, separated by "|".
Default completion codes are:
+
+
+
+
+ Plugin
+ Code
+ Description
+
+
+
+ &completions.xml;
+
+
+
+ Special codes:
Code
- Completion
+ Description
@@ -5052,71 +5067,6 @@ struct t_hook *weechat_hook_command (
%*
Repeat last completion
-
- %b
- Buffers names
-
-
- %B
- Buffers names (with plugin name)
-
-
- %c
- Configuration files
-
-
- %f
- Filename
-
-
- %F
- Filters
-
-
- %h
- Commands hooked
-
-
- %i
- Infos hooked
-
-
- %I
- Infolists hooked
-
-
- %n
- Nick
-
-
- %o
- Configuration option
-
-
- %p
- Plugin name
-
-
- %P
- Plugin commands
-
-
- %r
- Bar names
-
-
- %v
- Value of configuration option
-
-
- %w
- WeeChat commands
-
-
- %(xxx)
- Custom completion by plugin (xxx is a completion
- code added by a plugin)
-
@@ -5127,7 +5077,7 @@ struct t_hook *weechat_hook_command (
: function called when command is used,
arguments:
-
+
Type
@@ -5243,7 +5193,7 @@ struct t_hook *weechat_hook_command_run (
: function called when command is run,
arguments:
-
+
Type
@@ -5350,7 +5300,7 @@ struct t_hook *weechat_hook_timer (
: function called when time is reached,
arguments:
-
+
Type
@@ -5451,7 +5401,7 @@ struct t_hook *weechat_hook_fd (
: function called when a selected event
occurs, arguments:
-
+
Type
@@ -5545,7 +5495,7 @@ struct t_hook *weechat_hook_process (
: function called when data from child
is available, or when child has ended, arguments:
-
+
Type
@@ -5683,7 +5633,7 @@ struct t_hook *weechat_hook_connect (
: function called when connection is ok
or failed, arguments:
-
+
Type
@@ -5857,7 +5807,7 @@ struct t_hook *weechat_hook_print (
: function called when message is
printed, arguments:
-
+
Type
@@ -5980,7 +5930,7 @@ struct t_hook *weechat_hook_signal (
: function called when signal is
received, arguments:
-
+
diff --git a/doc/docgen.pl b/doc/docgen.pl
index 3faf9c347..6562cdb15 100644
--- a/doc/docgen.pl
+++ b/doc/docgen.pl
@@ -15,8 +15,8 @@
# along with this program. If not, see .
#
# Documentation generator for WeeChat: build XML include files with commands
# and options for WeeChat core and plugins.
#
# Instructions to build config files yourself in WeeChat directories (replace
# all paths with your path to WeeChat):
@@ -39,7 +39,7 @@ use File::Basename;
my $version = "0.1";
-# -------------------------------[ config ]-------------------------------------
+# -------------------------------[ config ]------------------------------------
# default path where doc XML files will be written (should be doc/ in sources
# package tree)
@@ -82,10 +82,14 @@ my @ignore_options = ("aspell\\.dict\\..*",
"logger\\.mask\\..*",
"weechat\\.proxy\\..*",
"weechat\\.bar\\..*",
- "weechat\\.debug\\..*",
- );
+ "weechat\\.debug\\..*");
-# --------------------------------[ init ]--------------------------------------
+# completions to ignore
+my @ignore_completions_plugins = ("jabber");
+my @ignore_completions_items = ("jabber.*",
+ "weeget.*");
+
+# -------------------------------[ init ]--------------------------------------
weechat::register("docgen", "FlashCode ", $version,
"GPL", "Doc generator for WeeChat 0.2.7", "", "");
@@ -93,7 +97,7 @@ weechat::hook_command("docgen", "Doc generator", "", "", "", "docgen");
weechat::config_set_plugin("path", $default_path)
if (weechat::config_get_plugin("path") eq "");
-# ------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
# get list of commands in a hash with 3 indexes: plugin, command, xxx
sub get_commands
@@ -192,6 +196,40 @@ sub get_infos
return %infos;
}
+# get list of completions hooked by plugins in a hash with 3 indexes: plugin, item, xxx
+sub get_completions
+{
+ my %completions;
+
+ # get completions hooked
+ my $infolist = weechat::infolist_get("hook", "", "completion");
+ while (weechat::infolist_next($infolist))
+ {
+ my $completion_item = weechat::infolist_string($infolist, "completion_item");
+ my $plugin = weechat::infolist_string($infolist, "plugin_name");
+ $plugin = "weechat" if ($plugin eq "");
+
+ # check if completion item is ignored or not
+ my $ignore = 0;
+ foreach my $mask (@ignore_completions_plugins)
+ {
+ $ignore = 1 if ($plugin =~ /${mask}/);
+ }
+ foreach my $mask (@ignore_completions_items)
+ {
+ $ignore = 1 if ($completion_item =~ /${mask}/);
+ }
+
+ if ($ignore ne 1)
+ {
+ $completions{$plugin}{$completion_item}{"description"} = weechat::infolist_string($infolist, "description");
+ }
+ }
+ weechat::infolist_free($infolist);
+
+ return %completions;
+}
+
# escape string for XML output
sub escape
{
@@ -207,6 +245,7 @@ sub docgen
my %plugin_commands = get_commands();
my %plugin_options = get_options();
my %plugin_infos = get_infos();
+ my %plugin_completions = get_completions();
# xml header (comment) for all files
my $xml_header =
@@ -235,6 +274,8 @@ sub docgen
my $num_files_options_updated = 0;
my $num_files_infos = 0;
my $num_files_infos_updated = 0;
+ my $num_files_completions = 0;
+ my $num_files_completions_updated = 0;
setlocale(LC_MESSAGES, $locale.".UTF-8");
my $d = Locale::gettext->domain_raw("weechat");
@@ -415,23 +456,65 @@ sub docgen
weechat::print("", weechat::prefix("error")."docgen error: unable to write file '$filename'");
}
}
+
+ # write completions hooked
+ my $filename = $dir."completions.xml";
+ if (open(FILE, ">".$filename.".tmp"))
+ {
+ print FILE $xml_header;
+ foreach my $plugin (sort keys %plugin_completions)
+ {
+ foreach my $completion_item (sort keys %{$plugin_completions{$plugin}})
+ {
+ my $description = $plugin_completions{$plugin}{$completion_item}{"description"};
+ $description = $d->get($description) if ($description ne "");
+
+ print FILE "\n";
+ print FILE " ".escape($plugin)."\n";
+ print FILE " ".escape($completion_item)."\n";
+ print FILE " ".escape($description)."\n";
+ print FILE "
\n";
+ }
+ }
+ #weechat::print("", "docgen: file ok: '$filename'");
+ my $rc = system("diff ".$filename." ".$filename.".tmp >/dev/null 2>&1");
+ if ($rc != 0)
+ {
+ system("mv -f ".$filename.".tmp ".$filename);
+ $num_files_updated++;
+ $num_files_completions_updated++;
+ }
+ else
+ {
+ system("rm ".$filename.".tmp");
+ }
+ $num_files++;
+ $num_files_completions++;
+ close(FILE);
+ }
+ else
+ {
+ weechat::print("", weechat::prefix("error")."docgen error: unable to write file '$filename'");
+ }
}
else
{
weechat::print("", weechat::prefix("error")."docgen error: directory '$dir' does not exist");
}
my $total_files = $num_files_commands + $num_files_options
- + $num_files_infos;
+ + $num_files_infos + $num_files_completions;
my $total_files_updated = $num_files_commands_updated + $num_files_options_updated
- + $num_files_infos_updated;
+ + $num_files_infos_updated + $num_files_completions_updated;
weechat::print("", "docgen: ".$locale.": ".$total_files." files ("
.$num_files_commands." cmd, "
.$num_files_options." opt, "
- .$num_files_infos." infos) -- "
+ .$num_files_infos." infos, "
+ .$num_files_completions." complt) -- "
.$total_files_updated." updated ("
.$num_files_commands_updated." cmd, "
.$num_files_options_updated." opt, "
- .$num_files_infos_updated." infos)");
+ .$num_files_infos_updated." infos, "
+ .$num_files_completions_updated." complt)");
}
weechat::print("", "docgen: total: ".$num_files." files (".$num_files_updated." updated)");
@@ -456,6 +539,8 @@ sub docgen
{
print FILE "\n";
}
+ print FILE "\n\n\n";
+ print FILE "\n";
close(FILE);
my $rc = system("diff ".$filename." ".$filename.".tmp >/dev/null 2>&1");
if ($rc != 0)
@@ -15,8 +15,8 @@
# along with this program. If not, see .
#
-# Documentation generator for WeeChat: build XML include files with commands
-# and options for WeeChat core and plugins.
+# Documentation generator for WeeChat: build XML include files with commands,
+# options, infos and completions for WeeChat core and plugins.
#
# Instructions to build config files yourself in WeeChat directories (replace